Installation:

pip install publish-notifier

Description:

Receives the message which was published to Kafka. It is used to transfer that message to another service which uses a data storage and stores the published message along with it's status.